// src/utils/helpers.ts
var formatDate = (date, includeTime = false) => {
  const options = includeTime ? {
    year: "numeric",
    month: "short",
    day: "numeric",
    hour: "2-digit",
    minute: "2-digit"
  } : { year: "numeric", month: "short", day: "numeric" };
  return date.toLocaleDateString(void 0, options);
};
var isDateString = (value) => !isNaN(Date.parse(value));
var trimText = (text, maxLength) => text.length > maxLength ? `${text.slice(0, maxLength)}...` : text;

// src/components/NoContentComponent.tsx
import { jsx, jsxs } from "react/jsx-runtime";
var NoContentComponent = ({ name }) => /* @__PURE__ */ jsx("div", { className: "text-center py-10", children: /* @__PURE__ */ jsxs("p", { className: "text-gray-500", children: [
  "No ",
  name,
  " found."
] }) });
var NoContentComponent_default = NoContentComponent;

// node_modules/react-loading-skeleton/dist/index.js
import React from "react";
var SkeletonThemeContext = React.createContext({});
var defaultEnableAnimation = true;
function styleOptionsToCssProperties({ baseColor, highlightColor, width, height, borderRadius, circle, direction, duration, enableAnimation = defaultEnableAnimation, customHighlightBackground }) {
  const style = {};
  if (direction === "rtl")
    style["--animation-direction"] = "reverse";
  if (typeof duration === "number")
    style["--animation-duration"] = `${duration}s`;
  if (!enableAnimation)
    style["--pseudo-element-display"] = "none";
  if (typeof width === "string" || typeof width === "number")
    style.width = width;
  if (typeof height === "string" || typeof height === "number")
    style.height = height;
  if (typeof borderRadius === "string" || typeof borderRadius === "number")
    style.borderRadius = borderRadius;
  if (circle)
    style.borderRadius = "50%";
  if (typeof baseColor !== "undefined")
    style["--base-color"] = baseColor;
  if (typeof highlightColor !== "undefined")
    style["--highlight-color"] = highlightColor;
  if (typeof customHighlightBackground === "string")
    style["--custom-highlight-background"] = customHighlightBackground;
  return style;
}
function Skeleton({ count = 1, wrapper: Wrapper, className: customClassName, containerClassName, containerTestId, circle = false, style: styleProp, ...originalPropsStyleOptions }) {
  var _a, _b, _c;
  const contextStyleOptions = React.useContext(SkeletonThemeContext);
  const propsStyleOptions = { ...originalPropsStyleOptions };
  for (const [key, value] of Object.entries(originalPropsStyleOptions)) {
    if (typeof value === "undefined") {
      delete propsStyleOptions[key];
    }
  }
  const styleOptions = {
    ...contextStyleOptions,
    ...propsStyleOptions,
    circle
  };
  const style = {
    ...styleProp,
    ...styleOptionsToCssProperties(styleOptions)
  };
  let className = "react-loading-skeleton";
  if (customClassName)
    className += ` ${customClassName}`;
  const inline = (_a = styleOptions.inline) !== null && _a !== void 0 ? _a : false;
  const elements = [];
  const countCeil = Math.ceil(count);
  for (let i = 0; i < countCeil; i++) {
    let thisStyle = style;
    if (countCeil > count && i === countCeil - 1) {
      const width = (_b = thisStyle.width) !== null && _b !== void 0 ? _b : "100%";
      const fractionalPart = count % 1;
      const fractionalWidth = typeof width === "number" ? width * fractionalPart : `calc(${width} * ${fractionalPart})`;
      thisStyle = { ...thisStyle, width: fractionalWidth };
    }
    const skeletonSpan = React.createElement("span", { className, style: thisStyle, key: i }, "\u200C");
    if (inline) {
      elements.push(skeletonSpan);
    } else {
      elements.push(React.createElement(
        React.Fragment,
        { key: i },
        skeletonSpan,
        React.createElement("br", null)
      ));
    }
  }
  return React.createElement("span", { className: containerClassName, "data-testid": containerTestId, "aria-live": "polite", "aria-busy": (_c = styleOptions.enableAnimation) !== null && _c !== void 0 ? _c : defaultEnableAnimation }, Wrapper ? elements.map((el, i) => React.createElement(Wrapper, { key: i }, el)) : elements);
}

// src/components/TableSkeleton.tsx
import { jsx as jsx2, jsxs as jsxs2 } from "react/jsx-runtime";
var TableSkeleton = ({
  disableDefaultStyles = false,
  customClassNames = {}
}) => {
  const defaultContainerClassName = "px-4 sm:px-6 lg:px-8";
  const defaultTableClassName = "min-w-full divide-y divide-gray-300";
  const defaultThClassName = "py-3.5 pl-4 pr-3 text-left text-sm font-semibold text-gray-900 sm:pl-3";
  const defaultTrClassName = (index) => index % 2 === 0 ? "bg-white" : "bg-gray-50";
  const defaultTdClassName = "whitespace-nowrap py-4 pl-4 pr-3 text-sm font-medium text-gray-900 sm:pl-3";
  const containerClassName = disableDefaultStyles ? customClassNames.container || "" : `${defaultContainerClassName} ${customClassNames.container || ""}`;
  const tableClassName = disableDefaultStyles ? customClassNames.table || "" : `${defaultTableClassName} ${customClassNames.table || ""}`;
  const thClassName = disableDefaultStyles ? customClassNames.th || "" : `${defaultThClassName} ${customClassNames.th || ""}`;
  const trClassName = (index) => disableDefaultStyles ? customClassNames.tr || "" : `${defaultTrClassName(index)} ${customClassNames.tr || ""}`;
  const tdClassName = disableDefaultStyles ? customClassNames.td || "" : `${defaultTdClassName} ${customClassNames.td || ""}`;
  return /* @__PURE__ */ jsx2("div", { className: containerClassName, children: /* @__PURE__ */ jsx2("div", { className: "mt-8 flow-root", children: /* @__PURE__ */ jsx2("div", { className: "-mx-4 -my-2 overflow-x-auto sm:-mx-6 lg:-mx-8", children: /* @__PURE__ */ jsx2("div", { className: "inline-block min-w-full py-2 align-middle sm:px-6 lg:px-8", children: /* @__PURE__ */ jsxs2("table", { className: tableClassName, children: [
    /* @__PURE__ */ jsx2("thead", { children: /* @__PURE__ */ jsxs2("tr", { children: [
      Array.from({ length: 4 }).map((_, index) => /* @__PURE__ */ jsx2("th", { scope: "col", className: thClassName, children: /* @__PURE__ */ jsx2(Skeleton, { width: 100 }) }, index)),
      /* @__PURE__ */ jsx2("th", { scope: "col", className: thClassName, children: /* @__PURE__ */ jsx2(Skeleton, { width: 50 }) })
    ] }) }),
    /* @__PURE__ */ jsx2("tbody", { children: Array.from({ length: 10 }).map((_, index) => /* @__PURE__ */ jsxs2("tr", { className: trClassName(index), children: [
      Array.from({ length: 4 }).map((_2, colIndex) => /* @__PURE__ */ jsx2("td", { className: tdClassName, children: /* @__PURE__ */ jsx2(Skeleton, { width: 150 }) }, colIndex)),
      /* @__PURE__ */ jsx2("td", { className: tdClassName, children: /* @__PURE__ */ jsx2(Skeleton, { width: 50 }) })
    ] }, index)) })
  ] }) }) }) }) });
};
var TableSkeleton_default = TableSkeleton;

// src/components/ActionDropdown.tsx
import { useState, useEffect, useRef } from "react";
import { createPortal } from "react-dom";
import { jsx as jsx3, jsxs as jsxs3 } from "react/jsx-runtime";
var ActionDropdown = ({
  item,
  index,
  actionTexts,
  actionFunctions,
  disableDefaultStyles = false,
  customClassNames = {}
}) => {
  const [isDropdownOpen, setIsDropdownOpen] = useState(false);
  const [dropdownPosition, setDropdownPosition] = useState({ top: 0, left: 0 });
  const buttonRef = useRef(null);
  const dropdownRef = useRef(null);
  const toggleDropdown = () => {
    if (buttonRef.current) {
      const rect = buttonRef.current.getBoundingClientRect();
      setDropdownPosition({
        top: rect.bottom + window.scrollY,
        left: Math.min(
          rect.left + window.scrollX - 10,
          window.innerWidth - 240
        )
      });
    }
    setIsDropdownOpen((prev) => !prev);
  };
  const handleClickOutside = (event) => {
    if (dropdownRef.current && !dropdownRef.current.contains(event.target) && buttonRef.current && !buttonRef.current.contains(event.target)) {
      setIsDropdownOpen(false);
    }
  };
  useEffect(() => {
    document.addEventListener("mousedown", handleClickOutside);
    return () => {
      document.removeEventListener("mousedown", handleClickOutside);
    };
  }, []);
  const handleDropdownClick = (event) => {
    event.stopPropagation();
  };
  const defaultTdClassName = "relative whitespace-nowrap py-4 pl-3 pr-4 text-right text-sm font-medium sm:pr-3";
  const defaultButtonClassName = "focus:outline-none";
  const defaultSvgClassName = "w-6 h-6 text-gray-500 hover:text-gray-700";
  const defaultDropdownMenuClassName = "absolute z-50 mt-1 w-48 bg-white shadow-md rounded-lg";
  const defaultDropdownItemClassName = "block w-full text-left px-4 py-2 text-sm text-gray-500 hover:bg-gray-100";
  const tdClassName = disableDefaultStyles ? customClassNames.actionTd || "" : `${defaultTdClassName} ${customClassNames.actionTd || ""}`;
  const buttonClassName = disableDefaultStyles ? customClassNames.actionButton || "" : `${defaultButtonClassName} ${customClassNames.actionButton || ""}`;
  const svgClassName = disableDefaultStyles ? customClassNames.actionSvg || "" : `${defaultSvgClassName} ${customClassNames.actionSvg || ""}`;
  const dropdownMenuClassName = disableDefaultStyles ? customClassNames.dropdownMenu || "" : `${defaultDropdownMenuClassName} ${customClassNames.dropdownMenu || ""}`;
  const dropdownItemClassName = disableDefaultStyles ? customClassNames.dropdownItem || "" : `${defaultDropdownItemClassName} ${customClassNames.dropdownItem || ""}`;
  const dropdownMenu = /* @__PURE__ */ jsx3(
    "div",
    {
      ref: dropdownRef,
      className: dropdownMenuClassName,
      style: {
        top: dropdownPosition.top,
        left: dropdownPosition.left,
        transform: "translateX(-10%)"
      },
      onClick: handleDropdownClick,
      children: actionTexts.map((text, i) => /* @__PURE__ */ jsx3(
        "button",
        {
          onClick: () => {
            actionFunctions[i](item);
            setIsDropdownOpen(false);
          },
          className: dropdownItemClassName,
          children: text
        },
        `action-${text}`
      ))
    }
  );
  return /* @__PURE__ */ jsxs3("td", { className: tdClassName, children: [
    /* @__PURE__ */ jsx3(
      "button",
      {
        ref: buttonRef,
        onClick: toggleDropdown,
        className: buttonClassName,
        children: /* @__PURE__ */ jsx3(
          "svg",
          {
            xmlns: "http://www.w3.org/2000/svg",
            fill: "none",
            viewBox: "0 0 24 24",
            stroke: "currentColor",
            className: svgClassName,
            children: /* @__PURE__ */ jsx3(
              "path",
              {
                strokeLinecap: "round",
                strokeLinejoin: "round",
                strokeWidth: 2,
                d: "M12 6h.01M12 12h.01M12 18h.01"
              }
            )
          }
        )
      }
    ),
    isDropdownOpen && createPortal(dropdownMenu, document.body)
  ] }, `actions-${index}`);
};
var ActionDropdown_default = ActionDropdown;

// src/components/TableComponent.tsx
import Link from "next/link";
import { jsx as jsx4, jsxs as jsxs4 } from "react/jsx-runtime";
function TableComponent({
  columns,
  data,
  props,
  actions,
  actionTexts,
  loading,
  actionFunctions,
  searchValue,
  disableDefaultStyles = false,
  customClassNames = {}
}) {
  if (!data || loading) {
    return /* @__PURE__ */ jsx4(TableSkeleton_default, {});
  }
  if (data.length === 0) {
    return /* @__PURE__ */ jsx4(NoContentComponent_default, { name: searchValue ?? "items" });
  }
  const defaultContainerClassName = "my-8 overflow-x-auto";
  const defaultTableClassName = "min-w-full divide-y divide-gray-200";
  const defaultTheadClassName = "bg-gray-50";
  const defaultThClassName = "px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider";
  const defaultTrClassName = (index) => index % 2 === 0 ? "bg-white" : "bg-gray-50";
  const defaultTdClassName = "px-6 py-4 whitespace-nowrap text-sm text-gray-700";
  const defaultActionTdClassName = "relative whitespace-nowrap py-4 pl-3 pr-4 text-right text-sm font-medium sm:pr-3";
  const containerClassName = disableDefaultStyles ? customClassNames.container || "" : `${defaultContainerClassName} ${customClassNames.container || ""}`;
  const tableClassName = disableDefaultStyles ? customClassNames.table || "" : `${defaultTableClassName} ${customClassNames.table || ""}`;
  const theadClassName = disableDefaultStyles ? customClassNames.thead || "" : `${defaultTheadClassName} ${customClassNames.thead || ""}`;
  const thClassName = disableDefaultStyles ? customClassNames.th || "" : `${defaultThClassName} ${customClassNames.th || ""}`;
  const trClassName = (index) => disableDefaultStyles ? customClassNames.tr || "" : `${defaultTrClassName(index)} ${customClassNames.tr || ""}`;
  const tdClassName = disableDefaultStyles ? customClassNames.td || "" : `${defaultTdClassName} ${customClassNames.td || ""}`;
  const actionTdClassName = disableDefaultStyles ? customClassNames.actionTd || "" : `${defaultActionTdClassName} ${customClassNames.actionTd || ""}`;
  return /* @__PURE__ */ jsx4("div", { className: containerClassName, children: /* @__PURE__ */ jsx4("div", { className: "inline-block min-w-full align-middle", children: /* @__PURE__ */ jsx4("div", { className: "overflow-hidden border border-gray-200 rounded-lg", children: /* @__PURE__ */ jsxs4("table", { className: tableClassName, children: [
    /* @__PURE__ */ jsx4("thead", { className: theadClassName, children: /* @__PURE__ */ jsxs4("tr", { children: [
      columns.map((column) => /* @__PURE__ */ jsx4("th", { scope: "col", className: thClassName, children: column }, column)),
      actions && actionTexts && /* @__PURE__ */ jsx4("th", { scope: "col", className: thClassName, children: /* @__PURE__ */ jsx4("span", { className: "sr-only", children: actionTexts.join(", ") }) })
    ] }) }),
    /* @__PURE__ */ jsx4("tbody", { children: data.map((item, dataIndex) => /* @__PURE__ */ jsxs4("tr", { className: trClassName(dataIndex), children: [
      props.map((prop) => {
        const value = item[prop];
        let displayValue;
        if (typeof value === "string" && isDateString(value)) {
          displayValue = formatDate(new Date(value), true);
        } else if (Array.isArray(value)) {
          displayValue = /* @__PURE__ */ jsx4("div", { className: "flex flex-wrap gap-1", children: value.map((chip, idx) => /* @__PURE__ */ jsx4(
            "span",
            {
              className: "inline-block bg-indigo-100 text-gray-800 px-2 py-1 rounded-full text-xs",
              children: trimText(String(chip), 20)
            },
            idx
          )) });
        } else if (typeof value === "string" && value.startsWith("http")) {
          displayValue = /* @__PURE__ */ jsx4(Link, { href: value, children: /* @__PURE__ */ jsx4(
            "span",
            {
              className: "text-blue-500 hover:underline",
              onClick: (e) => e.stopPropagation(),
              children: trimText(value, 30)
            }
          ) });
        } else {
          displayValue = trimText(String(value), 30);
        }
        return /* @__PURE__ */ jsx4("td", { className: tdClassName, children: displayValue }, String(prop));
      }),
      actions && actionTexts && actionFunctions && /* @__PURE__ */ jsx4(
        ActionDropdown_default,
        {
          item,
          index: dataIndex,
          actionTexts,
          actionFunctions,
          disableDefaultStyles,
          customClassNames
        }
      )
    ] }, dataIndex)) })
  ] }) }) }) });
}
var TableComponent_default = TableComponent;
export {
  ActionDropdown_default as ActionDropdown,
  NoContentComponent_default as NoContentComponent,
  TableComponent_default as TableComponent,
  TableSkeleton_default as TableSkeleton
};
